import { gql } from 'graphql-tag';

export const typeDefs = gql`
  type Group {
    id: ID!
    name: String!
    parentId: ID
    tasks: [Task!]!
    createdAt: String!
    updatedAt: String!
  }

  type Task {
    id: ID!
    title: String!
    groupId: ID!
    group: Group!
    steps: [Step!]!
    printCount: Int!
    lastPrintedAt: String
    createdAt: String!
    updatedAt: String!
  }

  type Step {
    id: ID!
    title: String!
    instructions: String!
    taskId: ID!
    task: Task!
    order: Int!
    images: [Image!]!
    printCount: Int!
    lastPrintedAt: String
    createdAt: String!
    updatedAt: String!
  }

  type Image {
    id: ID!
    stepId: ID!
    originalPath: String!
    bwPath: String!
    order: Int!
    createdAt: String!
    updatedAt: String!
  }

  type Query {
    groups: [Group!]!
    group(id: ID!): Group
    tasks(groupId: ID!): [Task!]!
    task(id: ID!): Task
    steps(taskId: ID!): [Step!]!
    step(id: ID!): Step
    recentTasks: [Task!]!
    frequentTasks: [Task!]!
  }

  type Mutation {
    createGroup(name: String!, parentId: ID): Group!
    createTask(title: String!, groupId: ID!): Task!
    createStep(title: String!, instructions: String!, taskId: ID!, order: Int!): Step!
    createImage(stepId: ID!, originalPath: String!, bwPath: String!, order: Int!): Image!
    printTask(id: ID!): Task!
    printStep(id: ID!): Step!
  }
`;